@@ -1,6 +1,6 @@
-import collections, re
+import collections, re, functools
 from unittest.case import TestCase
-from collections import namedtuple, Mapping
+from collections import namedtuple, Mapping, Iterable
 
 try:
     from repr import Repr
@@ -95,12 +95,50 @@ class KeyInspector(Inspector):
 
 class CallableInspector(Inspector):
     def returns(self, value):
+        """
+        returns is a synonym for equals only for called_with()
+        """
         return self._subject.equals(value)
 
     def __getattr__(self, item):
         return getattr(self._subject, item)
 
+class MultiInspector(Inspector):
+    """
+    Calls a list of inspector objects on a single subject.
+    """
+    def _get_inspector(self, subject):
+        return subject
+
+    def __getattr__(self, item):
+        # @functools.wraps(getattr(self._subject[0], item))
+        def inspect(*args, **kwargs):
+            sub_inspectors = []
+            for subject in self._subject:
+                inspector = self._get_inspector(subject)
+                inspect_method = getattr(inspector, item)
+                sub_inspectors.append(inspect_method(*args, **kwargs))
+            if not all(i == None for i in sub_inspectors):
+                return MultiInspector(sub_inspectors)
+        return inspect
+
+class MultiEnsure(MultiInspector):
+    """
+    Maps a single Ensure object to an iterable of subjects.
+    """
+    def __init__(self, iterable, inspector):
+        Inspector.__init__(self, iterable)
+        self._inspector = inspector
+        self._inspector(iterable).is_an(Iterable)
+
+    def _get_inspector(self, subject):
+        return self._inspector(subject)
+
 class Ensure(Inspector):
+    @classmethod
+    def each_of(cls, iterable):
+        return MultiEnsure(iterable, cls())
+
     def equals(self, other):
         self._run(unittest_case.assertEqual, (self._subject, other))
 
@@ -157,6 +195,14 @@ class Ensure(Inspector):
         self.contains(key)
         return KeyInspector(self._subject[key])
 
+    def has_keys(self, keys):
+        self.is_a(Mapping)
+        self.contains_all_of(keys)
+
+    def has_only_keys(self, keys):
+        self.is_a(Mapping)
+        self.contains_only(keys)
+
     def has_attribute(self, attr):
         if not hasattr(self._subject, attr):
             raise self._error_factory(_format("Expected {} to have attribute {}", self._subject, attr))
