@@ -51,9 +51,13 @@ class TestEnsure(unittest.TestCase):
         Ensure(0).is_a_nonnegative(int)
         Ensure((collections.namedtuple('Thing', ['x']))(x={})).has_attribute('x').which.is_a(dict)
         Ensure({1:"a"}).has_key(1).whose_value.has_length(1)
+        Ensure({1: "a", 2: "b", 3: "c"}).has_keys((1, 2))
+        Ensure({1: "a", 2: "b", 3: "c"}).has_only_keys((1, 2, 3))
         Ensure({}).is_empty()
         Ensure(os.path.join).called_with('a', 'b').returns(os.path.join('a', 'b'))
         Ensure(int).called_with("1100101", base=2).returns(101)
+        Ensure.each_of([1,2,3]).is_an(int)
+        Ensure.each_of([lambda x: x, lambda y: y]).called_with(1).returns(1)
 
         for assertion, args in ((Ensure(x).contains, [-1]),
                                 (Ensure(x).contains_all_of, [range(20)]),
@@ -81,7 +85,12 @@ class TestEnsure(unittest.TestCase):
                                 (Ensure(-0.1).is_nonnegative, []),
                                 (Ensure(None).is_a_nonnegative, [int]),
                                 (Ensure({1: "a"}).has_key(1).whose_value.has_length, [2]),
-                                (Ensure(os.path.join).called_with('a', 'b').returns, [None])):
+                                (Ensure({1: "a"}).has_keys, [(1, 2)]),
+                                (Ensure({1: "a", 2: "b"}).has_only_keys, [[1]]),
+                                (Ensure({1: "a", 2: "b"}).has_only_keys, [[1, 2, 3]]),
+                                (Ensure([1, 2, 3]).has_only_keys, [[1, 2, 3]]),
+                                (Ensure(os.path.join).called_with('a', 'b').returns, [None]),
+                                (Ensure.each_of([lambda x: x, lambda y: y]).called_with(2).returns, [1])):
             with self.assertRaises(EnsureError):
                 print(assertion, args)
                 assertion(*args)
